# pychoco

[![QA](https://github.com/Tatsh/pychoco/actions/workflows/qa.yml/badge.svg)](https://github.com/Tatsh/pychoco/actions/workflows/qa.yml)
[![Tests](https://github.com/Tatsh/pychoco/actions/workflows/tests.yml/badge.svg)](https://github.com/Tatsh/pychoco/actions/workflows/tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/Tatsh/pychoco/badge.svg?branch=master)](https://coveralls.io/github/Tatsh/pychoco?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pychoco/badge/?version=latest)](https://chocolatey-choco.readthedocs.org/?badge=latest)
[![PyPI - Version](https://img.shields.io/pypi/v/chocolatey-choco)](https://pypi.org/project/chocolatey-choco/)
[![GitHub tag (with filter)](https://img.shields.io/github/v/tag/Tatsh/pychoco)](https://github.com/Tatsh/pychoco/tags)
[![License](https://img.shields.io/github/license/Tatsh/pychoco)](https://github.com/Tatsh/pychoco/blob/master/LICENSE.txt)
[![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/Tatsh/pychoco/v0.1.3/master)](https://github.com/Tatsh/pychoco/compare/v0.1.3...master)

Minimal choco command for use on non-Windows platforms.

## Installation

### Poetry

```shell
poetry add pychoco
```

### Pip

```shell
pip install pychoco
```

## Usage

Add `-d` to show debug logs.

```shell
pychoco
```
